Page 71 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 71

Home

    They

    rejected

    laws,

    for

    rejected

    will

    we

    It had been observed that a pure democracy if it were
    practicable would be the most perfect government.
    Experience has proved that no position is more false than
    this. The ancient democracies in which the people
    themselves deliberated never possessed one good feature
    of government. Their very character was tyranny; their
    figure deformity.°

    Remember, Democracy never lasts long. It soon
    wastes, exhaust and murders itself! There never was a
    democracy that ‘did not commit suicide.”

    democracies have ever been spectacles of
    turbulence and contention; have ever been found
    incompatible with personal security, or the rights of

    66

    The Secret Side of History

    would do for them what they should do for themselves.

    of fixed

    government

    government based upon the whims of a monarch, the tragic

    results of which are recorded in the books of the Old

    Testament.

    Another system of government the Founding Fathers

    rejected was a Democracy.

    To understand why they

    let them speak for

    a Democracy,

    themselves.

    On June 21, 1788, Alexander Hamilton made a speech

    in which he stated:

    Samuel Adams warned:

    James Madison wrote: